summaryrefslogtreecommitdiff
path: root/odk/config/cfgWin.js
diff options
context:
space:
mode:
Diffstat (limited to 'odk/config/cfgWin.js')
-rw-r--r--odk/config/cfgWin.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/odk/config/cfgWin.js b/odk/config/cfgWin.js
index 128f3e2eafd5..f112e231b193 100644
--- a/odk/config/cfgWin.js
+++ b/odk/config/cfgWin.js
@@ -127,12 +127,12 @@ function getSdkHome()
continue;
}
}
- //Check if this is an sdk folder by looking for the idl sub - dir
- var idlDir = sHome + "\\idl";
- if (! aFileSystemObject.FolderExists(idlDir))
+ //Check if this is an sdk folder by looking for the examples sub - dir
+ var examplesDir = sHome + "\\examples";
+ if (! aFileSystemObject.FolderExists(examplesDir))
{
stdout.WriteLine("\n Error: Could not find directory \"" +
- idlDir + "\". An SDK is required, please specify " +
+ examplesDir + "\". An SDK is required, please specify " +
"the path to a valid SDK installation.");
continue;
}